@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2010-03-09T19:20:25-08 by Liar version 4.118. */
+/* generated 2011-10-15T20:33:35-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -116,27 +116,23 @@ INVOKE_INTERFACE_TARGET_1
 #define LABEL_2_14 19
 #define LABEL_2_15 21
 #define LABEL_2_16 23
-#define LABEL_2_18 25
-#define LABEL_2_19 27
-#define LABEL_2_20 29
-#define LABEL_2_21 31
-#define LABEL_2_17 33
-#define LABEL_2_22 35
-#define LABEL_2_23 37
-#define LABEL_2_24 39
-#define LABEL_2_25 41
-#define ENVIRONMENT_LABEL_2_3 55
-#define DEBUGGING_LABEL_2_2 54
-#define OBJECT_2_6 53
-#define OBJECT_2_5 52
-#define OBJECT_2_4 51
-#define OBJECT_2_3 50
-#define OBJECT_2_2 49
-#define OBJECT_2_1 48
-#define OBJECT_2_0 47
-#define EXECUTE_CACHE_2_10 43
-#define EXECUTE_CACHE_2_9 45
-#define FREE_REFERENCES_LABEL_2_0 42
+#define LABEL_2_17 25
+#define LABEL_2_18 27
+#define LABEL_2_19 29
+#define LABEL_2_20 31
+#define LABEL_2_21 33
+#define ENVIRONMENT_LABEL_2_3 47
+#define DEBUGGING_LABEL_2_2 46
+#define OBJECT_2_6 45
+#define OBJECT_2_5 44
+#define OBJECT_2_4 43
+#define OBJECT_2_3 42
+#define OBJECT_2_2 41
+#define OBJECT_2_1 40
+#define OBJECT_2_0 39
+#define EXECUTE_CACHE_2_10 35
+#define EXECUTE_CACHE_2_9 37
+#define FREE_REFERENCES_LABEL_2_0 34
 #define NUMBER_OF_LINKER_SECTIONS_2_1 1
 
 #ifndef WANT_ONLY_DATA
@@ -147,28 +143,6 @@ msort_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
   SCHEME_OBJECT * Rdl;
-  machine_word Wrd37;
-  machine_word Wrd36;
-  machine_word Wrd54;
-  machine_word Wrd50;
-  machine_word Wrd47;
-  machine_word Wrd56;
-  machine_word Wrd96;
-  machine_word Wrd97;
-  machine_word Wrd104;
-  machine_word Wrd101;
-  machine_word Wrd112;
-  machine_word Wrd106;
-  machine_word Wrd114;
-  machine_word Wrd88;
-  machine_word Wrd87;
-  machine_word Wrd69;
-  machine_word Wrd79;
-  machine_word Wrd76;
-  machine_word Wrd74;
-  machine_word Wrd73;
-  machine_word Wrd82;
-  machine_word Wrd81;
   machine_word Wrd43;
   machine_word Wrd46;
   machine_word Wrd45;
@@ -263,10 +237,13 @@ msort_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
   machine_word Wrd145;
   machine_word Wrd144;
   machine_word Wrd143;
+  machine_word Wrd141;
   machine_word Wrd139;
+  machine_word Wrd138;
   machine_word Wrd147;
   machine_word Wrd146;
   machine_word Wrd72;
+  machine_word Wrd190;
   machine_word Wrd19;
   machine_word Wrd17;
   machine_word Wrd13;
@@ -315,11 +292,11 @@ DEFLABEL (perform_dispatch)
 
     case 1:
       current_block = (Rpc - LABEL_2_4);
-      goto merge_sortB_40;
+      goto merge_sortB_32;
 
     case 2:
       current_block = (Rpc - LABEL_2_7);
-      goto label_42;
+      goto label_34;
 
     case 3:
       current_block = (Rpc - LABEL_2_6);
@@ -331,7 +308,7 @@ DEFLABEL (perform_dispatch)
 
     case 5:
       current_block = (Rpc - LABEL_2_11);
-      goto sort_subvector_38;
+      goto sort_subvector_30;
 
     case 6:
       current_block = (Rpc - LABEL_2_12);
@@ -343,64 +320,48 @@ DEFLABEL (perform_dispatch)
 
     case 8:
       current_block = (Rpc - LABEL_2_14);
-      goto merge_35;
+      goto continuation_18;
 
     case 9:
       current_block = (Rpc - LABEL_2_15);
-      goto label_47;
+      goto merge_27;
 
     case 10:
       current_block = (Rpc - LABEL_2_16);
-      goto label_48;
+      goto label_39;
 
     case 11:
-      current_block = (Rpc - LABEL_2_18);
-      goto label_45;
+      current_block = (Rpc - LABEL_2_17);
+      goto label_40;
 
     case 12:
-      current_block = (Rpc - LABEL_2_19);
-      goto label_46;
+      current_block = (Rpc - LABEL_2_18);
+      goto label_37;
 
     case 13:
-      current_block = (Rpc - LABEL_2_20);
-      goto label_43;
+      current_block = (Rpc - LABEL_2_19);
+      goto label_38;
 
     case 14:
-      current_block = (Rpc - LABEL_2_21);
-      goto label_44;
+      current_block = (Rpc - LABEL_2_20);
+      goto label_35;
 
     case 15:
-      current_block = (Rpc - LABEL_2_17);
-      goto continuation_22;
-
-    case 16:
-      current_block = (Rpc - LABEL_2_22);
-      goto label_51;
-
-    case 17:
-      current_block = (Rpc - LABEL_2_23);
-      goto label_52;
-
-    case 18:
-      current_block = (Rpc - LABEL_2_24);
-      goto label_49;
-
-    case 19:
-      current_block = (Rpc - LABEL_2_25);
-      goto label_50;
+      current_block = (Rpc - LABEL_2_21);
+      goto label_36;
 
     default:
       UNCACHE_VARIABLES ();
       return (Rpc);
     }
 
-DEFLABEL (merge_sortB_54)
-DEFLABEL (merge_sortB_40)
+DEFLABEL (merge_sortB_42)
+DEFLABEL (merge_sortB_32)
   INTERRUPT_CHECK (26, LABEL_2_4);
   (Wrd5.Obj) = (Rsp [0]);
   (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
   if ((Wrd6.uLng) == 10)
-    goto label_59;
+    goto label_47;
   (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
   (* (--Rsp)) = (Wrd9.Obj);
   (Wrd10.Obj) = (current_block [OBJECT_2_2]);
@@ -413,7 +374,7 @@ DEFLABEL (merge_sortB_40)
 DEFLABEL (continuation_1)
   INTERRUPT_CHECK (27, LABEL_2_5);
 
-DEFLABEL (label_59)
+DEFLABEL (label_47)
   (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
   (* (--Rsp)) = (Wrd15.Obj);
   (Wrd16.pObj) = (& (Rsp [1]));
@@ -422,13 +383,13 @@ DEFLABEL (label_59)
   (Wrd24.Obj) = (Rsp [2]);
   (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
   if (! ((Wrd25.uLng) == 10))
-    goto label_58;
+    goto label_46;
   (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
   (Wrd22.Obj) = ((Wrd21.pObj) [0]);
   (Wrd23.Obj) = (MAKE_OBJECT (26, (Wrd22.uLng)));
   (* (--Rsp)) = (Wrd23.Obj);
 
-DEFLABEL (label_57)
+DEFLABEL (label_45)
   (Wrd30.Obj) = (current_block [OBJECT_2_1]);
   (* (--Rsp)) = (Wrd30.Obj);
   (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
@@ -442,7 +403,7 @@ DEFLABEL (continuation_2)
   (* (--Rsp)) = Rvl;
   (Wrd5.Obj) = (Rsp [5]);
   (* (--Rsp)) = (Wrd5.Obj);
-  goto sort_subvector_38;
+  goto sort_subvector_30;
 
 DEFLABEL (continuation_4)
   INTERRUPT_CHECK (27, LABEL_2_6);
@@ -450,18 +411,18 @@ DEFLABEL (continuation_4)
   Rsp = (& (Rsp [2]));
   goto pop_return;
 
-DEFLABEL (label_58)
+DEFLABEL (label_46)
   (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
   (* (--Rsp)) = (Wrd29.Obj);
   (* (--Rsp)) = (Wrd24.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);
 
-DEFLABEL (label_42)
+DEFLABEL (label_34)
   (* (--Rsp)) = Rvl;
-  goto label_57;
+  goto label_45;
 
-DEFLABEL (sort_subvector_55)
-DEFLABEL (sort_subvector_38)
+DEFLABEL (sort_subvector_43)
+DEFLABEL (sort_subvector_30)
   INTERRUPT_CHECK (26, LABEL_2_11);
   (Wrd6.Obj) = (Rsp [3]);
   (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
@@ -469,12 +430,12 @@ DEFLABEL (sort_subvector_38)
   (Wrd9.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
   (Wrd11.Lng) = ((Wrd7.Lng) - (Wrd9.Lng));
   if ((Wrd11.Lng) > 1L)
-    goto label_60;
+    goto label_48;
   Rvl = (current_block [OBJECT_2_4]);
   Rsp = (& (Rsp [5]));
   goto pop_return;
 
-DEFLABEL (label_60)
+DEFLABEL (label_48)
   (Wrd22.Lng) = ((Wrd9.Lng) + (Wrd7.Lng));
   (Wrd25.Lng) = (((Wrd22.Lng) < 0) ? (RIGHT_SHIFT (((Wrd22.Lng) + 1), 1)) : (RIGHT_SHIFT ((Wrd22.Lng), 1)));
   (Wrd26.Obj) = (LONG_TO_FIXNUM (Wrd25.Lng));
@@ -494,7 +455,7 @@ DEFLABEL (label_60)
   (* (--Rsp)) = (Wrd38.Obj);
   (Wrd39.Obj) = (Rsp [8]);
   (* (--Rsp)) = (Wrd39.Obj);
-  goto sort_subvector_38;
+  goto sort_subvector_30;
 
 DEFLABEL (continuation_10)
   INTERRUPT_CHECK (27, LABEL_2_12);
@@ -516,7 +477,7 @@ DEFLABEL (continuation_10)
   (* (--Rsp)) = (Wrd18.Obj);
   (Wrd19.Obj) = (Rsp [8]);
   (* (--Rsp)) = (Wrd19.Obj);
-  goto sort_subvector_38;
+  goto sort_subvector_30;
 
 DEFLABEL (continuation_11)
   INTERRUPT_CHECK (27, LABEL_2_13);
@@ -527,66 +488,68 @@ DEFLABEL (continuation_11)
   (Wrd8.Obj) = (Rsp [4]);
   (* (--Rsp)) = (Wrd8.Obj);
   (* (--Rsp)) = (Wrd8.Obj);
-  goto merge_35;
+  goto merge_27;
 
-DEFLABEL (merge_56)
-DEFLABEL (merge_35)
-  DLINK_INTERRUPT_CHECK (25, LABEL_2_14);
+DEFLABEL (merge_44)
+DEFLABEL (merge_27)
+  DLINK_INTERRUPT_CHECK (25, LABEL_2_15);
   (Wrd5.Obj) = (Rsp [0]);
   (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
   (Wrd7.Obj) = (Rsp [7]);
   (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
   if ((Wrd6.Lng) < (Wrd8.Lng))
-    goto label_61;
+    goto label_49;
   Rvl = (current_block [OBJECT_2_4]);
   Rsp = Rdl;
   goto pop_return;
 
-DEFLABEL (label_61)
+DEFLABEL (label_49)
   (Wrd10.Obj) = (Rsp [1]);
   (Wrd11.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
   (Wrd12.Obj) = (Rsp [3]);
   (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
   if ((Wrd11.Lng) < (Wrd13.Lng))
-    goto label_66;
+    goto label_55;
+
+DEFLABEL (label_54)
   (Wrd28.Obj) = (Rsp [5]);
   (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
   if (! ((Wrd29.uLng) == 10))
-    goto label_65;
+    goto label_53;
   (Wrd20.Obj) = (Rsp [2]);
   (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
   if (! ((Wrd21.uLng) == 26))
-    goto label_65;
+    goto label_53;
   (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
   (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
   (Wrd26.Obj) = ((Wrd25.pObj) [0]);
   (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
   if (! (((unsigned long) (Wrd23.Lng)) < ((unsigned long) (Wrd27.Lng))))
-    goto label_65;
+    goto label_53;
   (Wrd16.uLng) = (OBJECT_DATUM (Wrd20.Obj));
   (Wrd19.pObj) = (& ((Wrd25.pObj) [(Wrd16.Lng)]));
   (Wrd14.Obj) = ((Wrd19.pObj) [1]);
 
-DEFLABEL (label_64)
+DEFLABEL (label_52)
   (Wrd60.Obj) = (Rsp [4]);
   (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
   if (! ((Wrd61.uLng) == 10))
-    goto label_63;
+    goto label_51;
   (Wrd52.Obj) = (Rsp [0]);
   (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
   if (! ((Wrd53.uLng) == 26))
-    goto label_63;
+    goto label_51;
   (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
   (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
   (Wrd58.Obj) = ((Wrd57.pObj) [0]);
   (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
   if (! (((unsigned long) (Wrd55.Lng)) < ((unsigned long) (Wrd59.Lng))))
-    goto label_63;
+    goto label_51;
   (Wrd48.uLng) = (OBJECT_DATUM (Wrd52.Obj));
   (Wrd51.pObj) = (& ((Wrd57.pObj) [(Wrd48.Lng)]));
   ((Wrd51.pObj) [1]) = (Wrd14.Obj);
 
-DEFLABEL (label_62)
+DEFLABEL (label_50)
   (Wrd40.Obj) = (Rsp [0]);
   (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
   (Wrd42.Lng) = ((Wrd41.Lng) + 1L);
@@ -597,9 +560,9 @@ DEFLABEL (label_62)
   (Wrd46.Lng) = ((Wrd45.Lng) + 1L);
   (Wrd43.Obj) = (LONG_TO_FIXNUM (Wrd46.Lng));
   (Rsp [2]) = (Wrd43.Obj);
-  goto merge_35;
+  goto merge_27;
 
-DEFLABEL (label_63)
+DEFLABEL (label_51)
   (Wrd66.Obj) = (Rsp [4]);
   (Wrd67.Obj) = (Rsp [0]);
   (Wrd65.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
@@ -611,12 +574,12 @@ DEFLABEL (label_63)
   (* (--Rsp)) = (Wrd66.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_2_6]), 3);
 
-DEFLABEL (label_44)
+DEFLABEL (label_36)
   (Wrd62.Obj) = (* (Rsp++));
   Rdl = (OBJECT_ADDRESS (Wrd62.Obj));
-  goto label_62;
+  goto label_50;
 
-DEFLABEL (label_65)
+DEFLABEL (label_53)
   (Wrd34.Obj) = (Rsp [5]);
   (Wrd35.Obj) = (Rsp [2]);
   (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
@@ -627,58 +590,58 @@ DEFLABEL (label_65)
   (* (--Rsp)) = (Wrd34.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
 
-DEFLABEL (label_43)
+DEFLABEL (label_35)
   (Wrd30.Obj) = (* (Rsp++));
   Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
   (Wrd14.Obj) = Rvl;
-  goto label_64;
+  goto label_52;
 
-DEFLABEL (label_66)
+DEFLABEL (label_55)
   (Wrd72.Obj) = (Rsp [2]);
   if ((Wrd72.Obj) == (Wrd7.Obj))
-    goto label_80;
+    goto label_60;
   (Wrd75.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
   (* (--Rsp)) = (Wrd75.Obj);
-  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_17]))));
+  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_14]))));
   (* (--Rsp)) = (Wrd78.Obj);
   (Wrd93.Obj) = (Rsp [7]);
   (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
   if (! ((Wrd94.uLng) == 10))
-    goto label_79;
+    goto label_64;
   (Wrd86.uLng) = (OBJECT_TYPE (Wrd10.Obj));
   if (! ((Wrd86.uLng) == 26))
-    goto label_79;
+    goto label_64;
   (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
   (Wrd91.Obj) = ((Wrd90.pObj) [0]);
   (Wrd92.Lng) = (FIXNUM_TO_LONG (Wrd91.Obj));
   if (! (((unsigned long) (Wrd11.Lng)) < ((unsigned long) (Wrd92.Lng))))
-    goto label_79;
+    goto label_64;
   (Wrd80.uLng) = (OBJECT_DATUM (Wrd10.Obj));
   (Wrd83.pObj) = (& ((Wrd90.pObj) [(Wrd80.Lng)]));
   (Wrd84.Obj) = ((Wrd83.pObj) [1]);
   (* (--Rsp)) = (Wrd84.Obj);
 
-DEFLABEL (label_78)
+DEFLABEL (label_63)
   (Wrd118.Obj) = (Rsp [8]);
   (Wrd119.uLng) = (OBJECT_TYPE (Wrd118.Obj));
   if (! ((Wrd119.uLng) == 10))
-    goto label_77;
+    goto label_62;
   (Wrd110.Obj) = (Rsp [5]);
   (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
   if (! ((Wrd111.uLng) == 26))
-    goto label_77;
+    goto label_62;
   (Wrd113.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
   (Wrd115.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
   (Wrd116.Obj) = ((Wrd115.pObj) [0]);
   (Wrd117.Lng) = (FIXNUM_TO_LONG (Wrd116.Obj));
   if (! (((unsigned long) (Wrd113.Lng)) < ((unsigned long) (Wrd117.Lng))))
-    goto label_77;
+    goto label_62;
   (Wrd105.uLng) = (OBJECT_DATUM (Wrd110.Obj));
   (Wrd108.pObj) = (& ((Wrd115.pObj) [(Wrd105.Lng)]));
   (Wrd109.Obj) = ((Wrd108.pObj) [1]);
   (* (--Rsp)) = (Wrd109.Obj);
 
-DEFLABEL (label_76)
+DEFLABEL (label_61)
   (Wrd129.Obj) = (Rsp [12]);
   (Wrd130.pObj) = (OBJECT_ADDRESS (Wrd129.Obj));
   (Wrd131.Obj) = ((Wrd130.pObj) [1]);
@@ -688,252 +651,52 @@ DEFLABEL (label_76)
     INVOKE_INTERFACE_2 (20, procedure, 3);
   }
 
-DEFLABEL (continuation_22)
-  INTERRUPT_CHECK (27, LABEL_2_17);
-  (Wrd5.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
-  if (Rvl == ((SCHEME_OBJECT) 0))
-    goto label_71;
-  (Wrd23.Obj) = (Rsp [5]);
-  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
-  if (! ((Wrd24.uLng) == 10))
-    goto label_70;
-  (Wrd15.Obj) = (Rsp [2]);
-  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
-  if (! ((Wrd16.uLng) == 26))
-    goto label_70;
-  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
-  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
-  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
-  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
-  if (! (((unsigned long) (Wrd18.Lng)) < ((unsigned long) (Wrd22.Lng))))
-    goto label_70;
-  (Wrd11.uLng) = (OBJECT_DATUM (Wrd15.Obj));
-  (Wrd14.pObj) = (& ((Wrd20.pObj) [(Wrd11.Lng)]));
-  (Wrd9.Obj) = ((Wrd14.pObj) [1]);
+DEFLABEL (continuation_18)
+  INTERRUPT_CHECK (27, LABEL_2_14);
+  (Wrd190.Obj) = (* (Rsp++));
+  Rdl = (OBJECT_ADDRESS (Wrd190.Obj));
+  if (! (Rvl == ((SCHEME_OBJECT) 0)))
+    goto label_54;
 
-DEFLABEL (label_69)
-  (Wrd55.Obj) = (Rsp [4]);
-  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
-  if (! ((Wrd56.uLng) == 10))
-    goto label_68;
-  (Wrd47.Obj) = (Rsp [0]);
-  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
-  if (! ((Wrd48.uLng) == 26))
-    goto label_68;
-  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
-  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
-  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
-  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
-  if (! (((unsigned long) (Wrd50.Lng)) < ((unsigned long) (Wrd54.Lng))))
-    goto label_68;
-  (Wrd43.uLng) = (OBJECT_DATUM (Wrd47.Obj));
-  (Wrd46.pObj) = (& ((Wrd52.pObj) [(Wrd43.Lng)]));
-  ((Wrd46.pObj) [1]) = (Wrd9.Obj);
-
-DEFLABEL (label_67)
-  (Wrd35.Obj) = (Rsp [0]);
-  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
-  (Wrd37.Lng) = ((Wrd36.Lng) + 1L);
-  (Wrd34.Obj) = (LONG_TO_FIXNUM (Wrd37.Lng));
-  (Rsp [0]) = (Wrd34.Obj);
-  (Wrd39.Obj) = (Rsp [2]);
-  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
-  (Wrd41.Lng) = ((Wrd40.Lng) + 1L);
-  (Wrd38.Obj) = (LONG_TO_FIXNUM (Wrd41.Lng));
-  (Rsp [2]) = (Wrd38.Obj);
-  goto merge_35;
-
-DEFLABEL (label_68)
-  (Wrd61.Obj) = (Rsp [4]);
-  (Wrd62.Obj) = (Rsp [0]);
-  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd60.Obj);
-  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_25]))));
-  (* (--Rsp)) = (Wrd66.Obj);
-  (* (--Rsp)) = (Wrd9.Obj);
-  (* (--Rsp)) = (Wrd62.Obj);
-  (* (--Rsp)) = (Wrd61.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_6]), 3);
-
-DEFLABEL (label_50)
-  (Wrd57.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd57.Obj));
-  goto label_67;
-
-DEFLABEL (label_70)
-  (Wrd29.Obj) = (Rsp [5]);
-  (Wrd30.Obj) = (Rsp [2]);
-  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd28.Obj);
-  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
-  (* (--Rsp)) = (Wrd33.Obj);
-  (* (--Rsp)) = (Wrd30.Obj);
-  (* (--Rsp)) = (Wrd29.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
-
-DEFLABEL (label_49)
-  (Wrd25.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
-  (Wrd9.Obj) = Rvl;
-  goto label_69;
-
-DEFLABEL (label_71)
-  (Wrd81.Obj) = (Rsp [5]);
-  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
-  if (! ((Wrd82.uLng) == 10))
-    goto label_75;
-  (Wrd73.Obj) = (Rsp [1]);
-  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
-  if (! ((Wrd74.uLng) == 26))
-    goto label_75;
-  (Wrd76.Lng) = (FIXNUM_TO_LONG (Wrd73.Obj));
-  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
-  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
-  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
-  if (! (((unsigned long) (Wrd76.Lng)) < ((unsigned long) (Wrd80.Lng))))
-    goto label_75;
-  (Wrd69.uLng) = (OBJECT_DATUM (Wrd73.Obj));
-  (Wrd72.pObj) = (& ((Wrd78.pObj) [(Wrd69.Lng)]));
-  (Wrd67.Obj) = ((Wrd72.pObj) [1]);
-
-DEFLABEL (label_74)
-  (Wrd113.Obj) = (Rsp [4]);
-  (Wrd114.uLng) = (OBJECT_TYPE (Wrd113.Obj));
-  if (! ((Wrd114.uLng) == 10))
-    goto label_73;
-  (Wrd105.Obj) = (Rsp [0]);
-  (Wrd106.uLng) = (OBJECT_TYPE (Wrd105.Obj));
-  if (! ((Wrd106.uLng) == 26))
-    goto label_73;
-  (Wrd108.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
-  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd113.Obj));
-  (Wrd111.Obj) = ((Wrd110.pObj) [0]);
-  (Wrd112.Lng) = (FIXNUM_TO_LONG (Wrd111.Obj));
-  if (! (((unsigned long) (Wrd108.Lng)) < ((unsigned long) (Wrd112.Lng))))
-    goto label_73;
-  (Wrd101.uLng) = (OBJECT_DATUM (Wrd105.Obj));
-  (Wrd104.pObj) = (& ((Wrd110.pObj) [(Wrd101.Lng)]));
-  ((Wrd104.pObj) [1]) = (Wrd67.Obj);
-
-DEFLABEL (label_72)
-  (Wrd93.Obj) = (Rsp [0]);
-  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
-  (Wrd95.Lng) = ((Wrd94.Lng) + 1L);
-  (Wrd92.Obj) = (LONG_TO_FIXNUM (Wrd95.Lng));
-  (Rsp [0]) = (Wrd92.Obj);
-  (Wrd97.Obj) = (Rsp [1]);
-  (Wrd98.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
-  (Wrd99.Lng) = ((Wrd98.Lng) + 1L);
-  (Wrd96.Obj) = (LONG_TO_FIXNUM (Wrd99.Lng));
-  (Rsp [1]) = (Wrd96.Obj);
-  goto merge_35;
-
-DEFLABEL (label_73)
-  (Wrd119.Obj) = (Rsp [4]);
-  (Wrd120.Obj) = (Rsp [0]);
-  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd118.Obj);
-  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_23]))));
-  (* (--Rsp)) = (Wrd124.Obj);
-  (* (--Rsp)) = (Wrd67.Obj);
-  (* (--Rsp)) = (Wrd120.Obj);
-  (* (--Rsp)) = (Wrd119.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_6]), 3);
-
-DEFLABEL (label_52)
-  (Wrd115.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd115.Obj));
-  goto label_72;
-
-DEFLABEL (label_75)
-  (Wrd87.Obj) = (Rsp [5]);
-  (Wrd88.Obj) = (Rsp [1]);
-  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd86.Obj);
-  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_22]))));
-  (* (--Rsp)) = (Wrd91.Obj);
-  (* (--Rsp)) = (Wrd88.Obj);
-  (* (--Rsp)) = (Wrd87.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
-
-DEFLABEL (label_51)
-  (Wrd83.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd83.Obj));
-  (Wrd67.Obj) = Rvl;
-  goto label_74;
-
-DEFLABEL (label_77)
-  (Wrd124.Obj) = (Rsp [8]);
-  (Wrd125.Obj) = (Rsp [5]);
-  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd123.Obj);
-  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
-  (* (--Rsp)) = (Wrd128.Obj);
-  (* (--Rsp)) = (Wrd125.Obj);
-  (* (--Rsp)) = (Wrd124.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
-
-DEFLABEL (label_46)
-  (Wrd120.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd120.Obj));
-  (* (--Rsp)) = Rvl;
-  goto label_76;
-
-DEFLABEL (label_79)
-  (Wrd99.Obj) = (Rsp [7]);
-  (Wrd100.Obj) = (Rsp [3]);
-  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
-  (* (--Rsp)) = (Wrd98.Obj);
-  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
-  (* (--Rsp)) = (Wrd103.Obj);
-  (* (--Rsp)) = (Wrd100.Obj);
-  (* (--Rsp)) = (Wrd99.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
-
-DEFLABEL (label_45)
-  (Wrd95.Obj) = (* (Rsp++));
-  Rdl = (OBJECT_ADDRESS (Wrd95.Obj));
-  (* (--Rsp)) = Rvl;
-  goto label_78;
-
-DEFLABEL (label_80)
+DEFLABEL (label_60)
   (Wrd146.Obj) = (Rsp [5]);
   (Wrd147.uLng) = (OBJECT_TYPE (Wrd146.Obj));
   if (! ((Wrd147.uLng) == 10))
-    goto label_84;
-  (Wrd139.uLng) = (OBJECT_TYPE (Wrd10.Obj));
+    goto label_59;
+  (Wrd138.Obj) = (Rsp [1]);
+  (Wrd139.uLng) = (OBJECT_TYPE (Wrd138.Obj));
   if (! ((Wrd139.uLng) == 26))
-    goto label_84;
+    goto label_59;
+  (Wrd141.Lng) = (FIXNUM_TO_LONG (Wrd138.Obj));
   (Wrd143.pObj) = (OBJECT_ADDRESS (Wrd146.Obj));
   (Wrd144.Obj) = ((Wrd143.pObj) [0]);
   (Wrd145.Lng) = (FIXNUM_TO_LONG (Wrd144.Obj));
-  if (! (((unsigned long) (Wrd11.Lng)) < ((unsigned long) (Wrd145.Lng))))
-    goto label_84;
-  (Wrd134.uLng) = (OBJECT_DATUM (Wrd10.Obj));
+  if (! (((unsigned long) (Wrd141.Lng)) < ((unsigned long) (Wrd145.Lng))))
+    goto label_59;
+  (Wrd134.uLng) = (OBJECT_DATUM (Wrd138.Obj));
   (Wrd137.pObj) = (& ((Wrd143.pObj) [(Wrd134.Lng)]));
   (Wrd132.Obj) = ((Wrd137.pObj) [1]);
 
-DEFLABEL (label_83)
+DEFLABEL (label_58)
   (Wrd178.Obj) = (Rsp [4]);
   (Wrd179.uLng) = (OBJECT_TYPE (Wrd178.Obj));
   if (! ((Wrd179.uLng) == 10))
-    goto label_82;
+    goto label_57;
   (Wrd170.Obj) = (Rsp [0]);
   (Wrd171.uLng) = (OBJECT_TYPE (Wrd170.Obj));
   if (! ((Wrd171.uLng) == 26))
-    goto label_82;
+    goto label_57;
   (Wrd173.Lng) = (FIXNUM_TO_LONG (Wrd170.Obj));
   (Wrd175.pObj) = (OBJECT_ADDRESS (Wrd178.Obj));
   (Wrd176.Obj) = ((Wrd175.pObj) [0]);
   (Wrd177.Lng) = (FIXNUM_TO_LONG (Wrd176.Obj));
   if (! (((unsigned long) (Wrd173.Lng)) < ((unsigned long) (Wrd177.Lng))))
-    goto label_82;
+    goto label_57;
   (Wrd166.uLng) = (OBJECT_DATUM (Wrd170.Obj));
   (Wrd169.pObj) = (& ((Wrd175.pObj) [(Wrd166.Lng)]));
   ((Wrd169.pObj) [1]) = (Wrd132.Obj);
 
-DEFLABEL (label_81)
+DEFLABEL (label_56)
   (Wrd158.Obj) = (Rsp [0]);
   (Wrd159.Lng) = (FIXNUM_TO_LONG (Wrd158.Obj));
   (Wrd160.Lng) = ((Wrd159.Lng) + 1L);
@@ -944,41 +707,75 @@ DEFLABEL (label_81)
   (Wrd164.Lng) = ((Wrd163.Lng) + 1L);
   (Wrd161.Obj) = (LONG_TO_FIXNUM (Wrd164.Lng));
   (Rsp [1]) = (Wrd161.Obj);
-  goto merge_35;
+  goto merge_27;
 
-DEFLABEL (label_82)
+DEFLABEL (label_57)
   (Wrd184.Obj) = (Rsp [4]);
   (Wrd185.Obj) = (Rsp [0]);
   (Wrd183.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
   (* (--Rsp)) = (Wrd183.Obj);
-  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
+  (Wrd189.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_17]))));
   (* (--Rsp)) = (Wrd189.Obj);
   (* (--Rsp)) = (Wrd132.Obj);
   (* (--Rsp)) = (Wrd185.Obj);
   (* (--Rsp)) = (Wrd184.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_2_6]), 3);
 
-DEFLABEL (label_48)
+DEFLABEL (label_40)
   (Wrd180.Obj) = (* (Rsp++));
   Rdl = (OBJECT_ADDRESS (Wrd180.Obj));
-  goto label_81;
+  goto label_56;
 
-DEFLABEL (label_84)
+DEFLABEL (label_59)
   (Wrd152.Obj) = (Rsp [5]);
   (Wrd153.Obj) = (Rsp [1]);
   (Wrd151.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
   (* (--Rsp)) = (Wrd151.Obj);
-  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
+  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
   (* (--Rsp)) = (Wrd156.Obj);
   (* (--Rsp)) = (Wrd153.Obj);
   (* (--Rsp)) = (Wrd152.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
 
-DEFLABEL (label_47)
+DEFLABEL (label_39)
   (Wrd148.Obj) = (* (Rsp++));
   Rdl = (OBJECT_ADDRESS (Wrd148.Obj));
   (Wrd132.Obj) = Rvl;
-  goto label_83;
+  goto label_58;
+
+DEFLABEL (label_62)
+  (Wrd124.Obj) = (Rsp [8]);
+  (Wrd125.Obj) = (Rsp [5]);
+  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
+  (* (--Rsp)) = (Wrd123.Obj);
+  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
+  (* (--Rsp)) = (Wrd128.Obj);
+  (* (--Rsp)) = (Wrd125.Obj);
+  (* (--Rsp)) = (Wrd124.Obj);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
+
+DEFLABEL (label_38)
+  (Wrd120.Obj) = (* (Rsp++));
+  Rdl = (OBJECT_ADDRESS (Wrd120.Obj));
+  (* (--Rsp)) = Rvl;
+  goto label_61;
+
+DEFLABEL (label_64)
+  (Wrd99.Obj) = (Rsp [7]);
+  (Wrd100.Obj) = (Rsp [3]);
+  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
+  (* (--Rsp)) = (Wrd98.Obj);
+  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_18]))));
+  (* (--Rsp)) = (Wrd103.Obj);
+  (* (--Rsp)) = (Wrd100.Obj);
+  (* (--Rsp)) = (Wrd99.Obj);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_2_5]), 2);
+
+DEFLABEL (label_37)
+  (Wrd95.Obj) = (* (Rsp++));
+  Rdl = (OBJECT_ADDRESS (Wrd95.Obj));
+  (* (--Rsp)) = Rvl;
+  goto label_63;
 
 INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
@@ -1011,7 +808,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-msort_so_8d51c6c43f962d34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+msort_so_dac4c332b8466cce (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1167,77 +964,75 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_msort_so_8d51c6c43f962d34 [2] =
+static const struct liarc_code_S arr_decl_msort_so_dac4c332b8466cce [2] =
   {
     { "msort_so_code_1", 4, msort_so_code_1 },
-    { "msort_so_code_2", 20, msort_so_code_2 }
+    { "msort_so_code_2", 16, msort_so_code_2 }
   };
 
 int
-decl_msort_so_8d51c6c43f962d34 (void)
+decl_msort_so_dac4c332b8466cce (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_msort_so_8d51c6c43f962d34);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_msort_so_dac4c332b8466cce);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("msort.so", 7, decl_msort_so_8d51c6c43f962d34, msort_so_8d51c6c43f962d34)
+DECLARE_COMPILED_CODE ("msort.so", 7, decl_msort_so_dac4c332b8466cce, msort_so_dac4c332b8466cce)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_msort_so_data_8d51c6c43f962d34 [575] =
-  "\x3c\x05\x82\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
-  "\x0d\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x2b\xbb\x1d\xb0\x82\x88\xc3\xc2\x1d\x0c\xb2\x80\xc1\x28\xb1"
-  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb9\x99"
-  "\xb8\x88\xb0\x0d\xc3\x0d\xb2\x0d\xb8\x99\xb1\x2a\xb3\x2a\x99\x28"
-  "\x0d\x26\xb0\xb2\x24\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x21\x17\x02\x46\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x30\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
-  "\x6d\x65\x2f\x6d\x73\x6f\x72\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70"
-  "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
-  "\x5d\x02\x03\x0c\x76\x65\x63\x74\x6f\x72\x2d\x63\x6f\x70\x79\x03"
-  "\x0d\x6c\x69\x73\x74\x2d\x3e\x76\x65\x63\x74\x6f\x72\x03\x0d\x76"
-  "\x65\x63\x74\x6f\x72\x2d\x3e\x6c\x69\x73\x74\x04\x0c\x6d\x65\x72"
-  "\x67\x65\x2d\x73\x6f\x72\x74\x21\x05\x0b\x0a\x81\x85\x02\x0a\x08"
-  "\x81\x89\x02\x09\x06\x81\x85\x02\x08\x04\x84\x06\x09\x15\x02\x0c"
-  "\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x0b\x76\x65\x63\x74"
-  "\x6f\x72\x2d\x72\x65\x66\x02\x07\x76\x65\x63\x74\x6f\x72\x0e\x76"
-  "\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x03\x05\x1a\x65"
-  "\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d"
-  "\x61\x72\x67\x75\x6d\x65\x6e\x74\x03\x1f\x2a\xfd\xff\x03\x1e\x28"
-  "\xfd\xff\x03\x1d\x26\xfd\xff\x03\x1c\x24\xfd\xff\x03\x1b\x22\xfd"
-  "\xff\x03\x1a\x20\xfd\xff\x03\x19\x1e\xfd\xff\x03\x18\x1c\xfd\xff"
-  "\x03\x17\x1a\xfd\xff\x03\x16\x18\xfd\xff\x03\x15\x16\xfd\xff\x03"
-  "\x14\x14\xff\xff\x03\x13\x12\xfd\xff\x03\x12\x10\xfd\xff\x03\x11"
-  "\x0e\x81\x8b\x02\x10\x0c\x81\x8d\x02\x0f\x0a\x81\x85\x02\x0e\x08"
-  "\x81\x89\x02\x0d\x06\x84\x06\x0c\x04\x81\x85\x02\x29\x38\x06\x73"
-  "\x6f\x72\x74\x21\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67"
-  "\x6e\x6d\x65\x6e\x74\x05\x73\x6f\x72\x74\x0b\x6d\x65\x72\x67\x65"
-  "\x2d\x73\x6f\x72\x74\x06\x04\x05\x10\x64\x65\x66\x69\x6e\x65\x2d"
-  "\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x03\x07\x10\x80\x80\x04\x06"
-  "\x0e\x81\x81\x02\x05\x0c\x81\x81\x02\x04\x0a\x81\x87\x02\x03\x08"
-  "\x81\x83\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0f\x1f";
+static const unsigned char prog_msort_so_data_dac4c332b8466cce [542] =
+  "\x34\x05\x7a\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28\x0d"
+  "\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
+  "\x2b\xbb\x1d\xb0\x82\x88\xc3\xc2\x1d\x0c\xb2\x80\xc1\x28\xb1\x28"
+  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
+  "\x22\x29\x21\x17\x2b\xb9\x99\xb8\x88\xb0\x0d\xc3\x0d\xb2\x0d\xb8"
+  "\x99\xb1\x2a\xb3\x2a\x99\x28\x0d\x26\xb0\xb2\x24\x22\x29\x22\x29"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
+  "\x6e\x74\x69\x6d\x65\x2f\x6d\x73\x6f\x72\x74\x2e\x69\x6e\x66\x15"
+  "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
+  "\x6f\x6f\x74\x5d\x02\x03\x0c\x76\x65\x63\x74\x6f\x72\x2d\x63\x6f"
+  "\x70\x79\x03\x0d\x6c\x69\x73\x74\x2d\x3e\x76\x65\x63\x74\x6f\x72"
+  "\x03\x0d\x76\x65\x63\x74\x6f\x72\x2d\x3e\x6c\x69\x73\x74\x04\x0c"
+  "\x6d\x65\x72\x67\x65\x2d\x73\x6f\x72\x74\x21\x05\x0b\x0a\x81\x85"
+  "\x02\x0a\x08\x81\x89\x02\x09\x06\x81\x85\x02\x08\x04\x84\x06\x09"
+  "\x15\x02\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x0b\x76"
+  "\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x02\x07\x76\x65\x63\x74\x6f"
+  "\x72\x0e\x76\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x03"
+  "\x05\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79"
+  "\x70\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x03\x1b\x22\xfd\xff"
+  "\x03\x1a\x20\xfd\xff\x03\x19\x1e\xfd\xff\x03\x18\x1c\xfd\xff\x03"
+  "\x17\x1a\xfd\xff\x03\x16\x18\xfd\xff\x03\x15\x16\xff\xff\x03\x14"
+  "\x14\xfd\xff\x03\x13\x12\xfd\xff\x03\x12\x10\xfd\xff\x03\x11\x0e"
+  "\x81\x8b\x02\x10\x0c\x81\x8d\x02\x0f\x0a\x81\x85\x02\x0e\x08\x81"
+  "\x89\x02\x0d\x06\x84\x06\x0c\x04\x81\x85\x02\x21\x30\x06\x73\x6f"
+  "\x72\x74\x21\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e"
+  "\x6d\x65\x6e\x74\x05\x73\x6f\x72\x74\x0b\x6d\x65\x72\x67\x65\x2d"
+  "\x73\x6f\x72\x74\x06\x04\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d"
+  "\x75\x6c\x74\x69\x70\x6c\x65\x02\x03\x07\x10\x80\x80\x04\x06\x0e"
+  "\x81\x81\x02\x05\x0c\x81\x81\x02\x04\x0a\x81\x87\x02\x03\x08\x81"
+  "\x83\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0f\x1f";
 
 SCHEME_OBJECT *
-msort_so_data_8d51c6c43f962d34 (entry_count_t dispatch_base)
+msort_so_data_dac4c332b8466cce (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_msort_so_data_8d51c6c43f962d34 [0]))), (sizeof (prog_msort_so_data_8d51c6c43f962d34)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_msort_so_data_dac4c332b8466cce [0]))), (sizeof (prog_msort_so_data_dac4c332b8466cce)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("msort.so", msort_so_data_8d51c6c43f962d34)
+DECLARE_COMPILED_DATA_NS ("msort.so", msort_so_data_dac4c332b8466cce)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("msort.so", "40313bdf53cbbefe")
+DECLARE_DYNAMIC_INITIALIZATION ("msort.so", "dfc001c54a792eb2")
