@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2010-03-09T19:21:12-08 by Liar version 4.118. */
+/* generated 2011-10-15T20:34:04-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -480,30 +480,26 @@ INVOKE_INTERFACE_TARGET_1
 
 #define LABEL_5_4 3
 #define LABEL_5_5 5
-#define LABEL_5_7 7
-#define TAG_5_8 2
-#define LABEL_5_9 9
-#define TAG_5_10 3
-#define LABEL_5_14 11
-#define LABEL_5_15 13
-#define LABEL_5_16 15
-#define LABEL_5_17 17
-#define LABEL_5_11 19
-#define TAG_5_12 8
-#define LABEL_5_18 21
-#define LABEL_5_19 23
-#define LABEL_5_20 25
-#define LABEL_5_21 27
-#define ENVIRONMENT_LABEL_5_3 41
-#define DEBUGGING_LABEL_5_2 40
-#define OBJECT_5_0 39
-#define EXECUTE_CACHE_5_13 29
-#define EXECUTE_CACHE_5_6 31
-#define FREE_REFERENCE_5_1 34
-#define FREE_REFERENCE_5_0 35
-#define FREE_ASSIGNMENT_5_1 37
-#define FREE_ASSIGNMENT_5_0 38
-#define FREE_REFERENCES_LABEL_5_0 28
+#define LABEL_5_9 7
+#define TAG_5_10 2
+#define LABEL_5_7 9
+#define TAG_5_8 3
+#define LABEL_5_12 11
+#define LABEL_5_13 13
+#define LABEL_5_14 15
+#define LABEL_5_15 17
+#define LABEL_5_16 19
+#define LABEL_5_17 21
+#define ENVIRONMENT_LABEL_5_3 35
+#define DEBUGGING_LABEL_5_2 34
+#define OBJECT_5_0 33
+#define EXECUTE_CACHE_5_11 23
+#define EXECUTE_CACHE_5_6 25
+#define FREE_REFERENCE_5_1 28
+#define FREE_REFERENCE_5_0 29
+#define FREE_ASSIGNMENT_5_1 31
+#define FREE_ASSIGNMENT_5_0 32
+#define FREE_REFERENCES_LABEL_5_0 22
 #define NUMBER_OF_LINKER_SECTIONS_5_1 3
 
 #ifndef WANT_ONLY_DATA
@@ -514,49 +510,46 @@ wrkdir_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
   SCHEME_OBJECT * Rdl;
-  machine_word Wrd92;
-  machine_word Wrd91;
-  machine_word Wrd90;
+  machine_word Wrd106;
+  machine_word Wrd105;
+  machine_word Wrd97;
   machine_word Wrd89;
   machine_word Wrd88;
+  machine_word Wrd87;
+  machine_word Wrd86;
+  machine_word Wrd85;
   machine_word Wrd84;
-  machine_word Wrd83;
-  machine_word Wrd76;
-  machine_word Wrd75;
-  machine_word Wrd63;
-  machine_word Wrd68;
-  machine_word Wrd67;
-  machine_word Wrd64;
-  machine_word Wrd60;
+  machine_word Wrd80;
+  machine_word Wrd79;
+  machine_word Wrd70;
+  machine_word Wrd69;
+  machine_word Wrd57;
+  machine_word Wrd62;
+  machine_word Wrd61;
+  machine_word Wrd58;
+  machine_word Wrd54;
   machine_word Wrd53;
-  machine_word Wrd48;
-  machine_word Wrd46;
   machine_word Wrd45;
-  machine_word Wrd44;
+  machine_word Wrd37;
+  machine_word Wrd36;
+  machine_word Wrd35;
+  machine_word Wrd34;
+  machine_word Wrd33;
   machine_word Wrd32;
-  machine_word Wrd31;
-  machine_word Wrd19;
-  machine_word Wrd20;
+  machine_word Wrd18;
+  machine_word Wrd17;
   machine_word Wrd9;
   machine_word Wrd5;
-  machine_word Wrd47;
-  machine_word Wrd39;
-  machine_word Wrd40;
-  machine_word Wrd36;
-  machine_word Wrd28;
-  machine_word Wrd29;
-  machine_word Wrd26;
-  machine_word Wrd25;
-  machine_word Wrd23;
-  machine_word Wrd24;
-  machine_word Wrd52;
-  machine_word Wrd51;
-  machine_word Wrd17;
-  machine_word Wrd16;
   machine_word Wrd13;
   machine_word Wrd12;
-  machine_word Wrd6;
   machine_word Wrd10;
+  machine_word Wrd11;
+  machine_word Wrd21;
+  machine_word Wrd25;
+  machine_word Wrd24;
+  machine_word Wrd28;
+  machine_word Wrd27;
+  machine_word Wrd6;
   machine_word Wrd8;
   machine_word Wrd7;
   INVOKE_INTERFACE_DECLS
@@ -572,63 +565,51 @@ DEFLABEL (perform_dispatch)
     {
     case 0:
       current_block = (Rpc - LABEL_5_4);
-      goto with_working_directory_pathname_30;
+      goto with_working_directory_pathname_17;
 
     case 1:
       current_block = (Rpc - LABEL_5_5);
       goto continuation_0;
 
     case 2:
-      current_block = (Rpc - LABEL_5_7);
-      goto lambda_42;
+      current_block = (Rpc - LABEL_5_9);
+      goto lambda_28;
 
     case 3:
-      current_block = (Rpc - LABEL_5_9);
-      goto lambda_43;
+      current_block = (Rpc - LABEL_5_7);
+      goto swapB_27;
 
     case 4:
-      current_block = (Rpc - LABEL_5_14);
-      goto label_32;
+      current_block = (Rpc - LABEL_5_12);
+      goto label_19;
 
     case 5:
-      current_block = (Rpc - LABEL_5_15);
-      goto label_33;
+      current_block = (Rpc - LABEL_5_13);
+      goto label_20;
 
     case 6:
-      current_block = (Rpc - LABEL_5_16);
-      goto label_34;
+      current_block = (Rpc - LABEL_5_14);
+      goto label_21;
 
     case 7:
-      current_block = (Rpc - LABEL_5_17);
-      goto label_35;
+      current_block = (Rpc - LABEL_5_15);
+      goto label_22;
 
     case 8:
-      current_block = (Rpc - LABEL_5_11);
-      goto lambda_44;
+      current_block = (Rpc - LABEL_5_16);
+      goto label_23;
 
     case 9:
-      current_block = (Rpc - LABEL_5_18);
-      goto label_36;
-
-    case 10:
-      current_block = (Rpc - LABEL_5_19);
-      goto label_37;
-
-    case 11:
-      current_block = (Rpc - LABEL_5_20);
-      goto label_38;
-
-    case 12:
-      current_block = (Rpc - LABEL_5_21);
-      goto label_39;
+      current_block = (Rpc - LABEL_5_17);
+      goto label_24;
 
     default:
       UNCACHE_VARIABLES ();
       return (Rpc);
     }
 
-DEFLABEL (with_working_directory_pathname_41)
-DEFLABEL (with_working_directory_pathname_30)
+DEFLABEL (with_working_directory_pathname_26)
+DEFLABEL (with_working_directory_pathname_17)
   INTERRUPT_CHECK (26, LABEL_5_4);
   (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
   (* (--Rsp)) = (Wrd7.Obj);
@@ -639,71 +620,47 @@ DEFLABEL (with_working_directory_pathname_30)
 DEFLABEL (continuation_0)
   INTERRUPT_CHECK (27, LABEL_5_5);
   (* (--Rsp)) = Rvl;
-  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
-  (* (Rhp++)) = (Wrd10.Obj);
+  (* (Rhp++)) = Rvl;
   (Wrd6.pObj) = (& (Rhp [-1]));
   (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
   (* (--Rsp)) = (Wrd7.Obj);
-  (* (Rhp++)) = Rvl;
-  (Wrd12.pObj) = (& (Rhp [-1]));
-  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
-  (* (--Rsp)) = (Wrd13.Obj);
-  (* (Rhp++)) = Rvl;
-  (Wrd16.pObj) = (& (Rhp [-1]));
-  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd16.pObj)));
-  (* (--Rsp)) = (Wrd17.Obj);
-  (Rsp [3]) = (Wrd10.Obj);
-  (* (Rhp++)) = (Wrd10.Obj);
-  (Wrd51.pObj) = (& (Rhp [-1]));
-  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd51.pObj)));
-  (Rsp [3]) = (Wrd52.Obj);
-  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
-  (Wrd24.pObj) = (Rhp + 1);
+  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
+  (Wrd27.pObj) = (Rhp + 1);
   Rhp += 1;
   WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
   (* (Rhp++)) = (dispatch_base + TAG_5_8);
   (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_7])));
-  Rhp += 1;
-  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
-  Wrd25 = Wrd24;
-  (Wrd26.Obj) = (Rsp [5]);
-  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
-  (Rsp [4]) = (Wrd23.Obj);
-  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
-  (Wrd29.pObj) = (Rhp + 1);
+  Rhp += 2;
+  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd27.pObj)));
+  (* (--Rsp)) = (Wrd28.Obj);
+  (* (Rhp++)) = Rvl;
+  (Wrd24.pObj) = (& (Rhp [-1]));
+  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
+  (Rsp [2]) = (Wrd25.Obj);
+  Wrd21 = Wrd27;
+  ((Wrd21.pObj) [2]) = (Wrd25.Obj);
+  ((Wrd21.pObj) [3]) = (Wrd7.Obj);
+  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
+  (Wrd11.pObj) = (Rhp + 1);
   Rhp += 1;
   WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
   (* (Rhp++)) = (dispatch_base + TAG_5_10);
   (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_9])));
-  Rhp += 4;
-  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
-  Wrd36 = Wrd29;
-  ((Wrd36.pObj) [2]) = (Wrd52.Obj);
-  ((Wrd36.pObj) [3]) = (Wrd7.Obj);
-  ((Wrd36.pObj) [4]) = (Wrd13.Obj);
-  ((Wrd36.pObj) [5]) = (Wrd17.Obj);
-  (Rsp [5]) = (Wrd28.Obj);
-  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
-  (Wrd40.pObj) = (Rhp + 1);
   Rhp += 1;
-  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
-  (* (Rhp++)) = (dispatch_base + TAG_5_12);
-  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_11])));
-  Rhp += 4;
-  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd40.pObj)));
-  Wrd47 = Wrd40;
-  ((Wrd47.pObj) [2]) = (Wrd52.Obj);
-  ((Wrd47.pObj) [3]) = (Wrd7.Obj);
-  ((Wrd47.pObj) [4]) = (Wrd13.Obj);
-  ((Wrd47.pObj) [5]) = (Wrd17.Obj);
-  (Rsp [3]) = (Wrd39.Obj);
-  Rsp = (& (Rsp [3]));
-  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_13]));
+  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
+  Wrd12 = Wrd11;
+  (Wrd13.Obj) = (Rsp [4]);
+  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
+  (Rsp [3]) = (Wrd10.Obj);
+  (Rsp [4]) = (Wrd28.Obj);
+  (Rsp [2]) = (Wrd28.Obj);
+  Rsp = (& (Rsp [2]));
+  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_11]));
 
-DEFLABEL (lambda_42)
-  CLOSURE_HEADER (LABEL_5_7);
+DEFLABEL (lambda_28)
+  CLOSURE_HEADER (LABEL_5_9);
 
-DEFLABEL (lambda_14)
+DEFLABEL (lambda_1)
   CLOSURE_INTERRUPT_CHECK (24);
   (Wrd6.Obj) = (Rsp [0]);
   (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
@@ -714,243 +671,150 @@ DEFLABEL (lambda_14)
     INVOKE_INTERFACE_2 (20, procedure, 1);
   }
 
-DEFLABEL (lambda_43)
-  CLOSURE_HEADER (LABEL_5_9);
+DEFLABEL (swapB_27)
+  CLOSURE_HEADER (LABEL_5_7);
 
-DEFLABEL (lambda_27)
+DEFLABEL (swapB_14)
   CLOSURE_INTERRUPT_CHECK (24);
-  (Wrd5.Obj) = (Rsp [0]);
-  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
-  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
-  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
-  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
-  (* (--Rsp)) = (Wrd9.Obj);
-  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
-  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
-  Rsp = (& (Rsp [1]));
-  (* (--Rsp)) = (Wrd9.Obj);
-  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
-  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
-  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
-  if ((Wrd24.uLng) == 50)
-    goto label_56;
-
-DEFLABEL (label_55)
-  Wrd19 = Wrd23;
-
-DEFLABEL (label_54)
-  (* (--Rsp)) = (Wrd19.Obj);
-  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_0]));
-  (Wrd32.Obj) = (Rsp [1]);
-  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
-  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
-  if ((Wrd40.uLng) == 50)
-    goto label_53;
-
-DEFLABEL (label_52)
-  ((Wrd31.pObj) [0]) = (Wrd32.Obj);
-
-DEFLABEL (label_51)
-  (Wrd44.Obj) = (Rsp [0]);
-  Rsp = (& (Rsp [2]));
-  (Wrd45.Obj) = (Rsp [0]);
-  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
-  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
-  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
-  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
-  (Wrd51.Obj) = ((Wrd46.pObj) [2]);
-  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
-  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
-  (* (--Rsp)) = (Wrd53.Obj);
-  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
-  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
-  Rsp = (& (Rsp [1]));
-  (* (--Rsp)) = (Wrd53.Obj);
-  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_1]));
-  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
-  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
-  if ((Wrd68.uLng) == 50)
-    goto label_50;
-
-DEFLABEL (label_49)
-  Wrd63 = Wrd67;
-
-DEFLABEL (label_48)
-  (* (--Rsp)) = (Wrd63.Obj);
-  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_1]));
-  (Wrd76.Obj) = (Rsp [1]);
-  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
-  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
-  if ((Wrd84.uLng) == 50)
-    goto label_47;
-
-DEFLABEL (label_46)
-  ((Wrd75.pObj) [0]) = (Wrd76.Obj);
+  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
+  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
+  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
+  if ((Wrd10.uLng) == 50)
+    goto label_46;
 
 DEFLABEL (label_45)
-  (Wrd88.Obj) = (Rsp [0]);
+  Wrd5 = Wrd9;
+
+DEFLABEL (label_44)
+  (* (--Rsp)) = (Wrd5.Obj);
+  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_0]));
+  (Wrd18.Obj) = (MAKE_OBJECT (50, 0));
+  (Wrd27.Obj) = ((Wrd17.pObj) [0]);
+  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
+  if ((Wrd28.uLng) == 50)
+    goto label_43;
+
+DEFLABEL (label_42)
+  ((Wrd17.pObj) [0]) = (Wrd18.Obj);
+
+DEFLABEL (label_41)
+  (Wrd32.Obj) = (Rsp [0]);
+  Rsp = (& (Rsp [1]));
+  (* (--Rsp)) = (Wrd32.Obj);
+  (Wrd33.Obj) = (Rsp [1]);
+  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
+  (Wrd35.Obj) = ((Wrd34.pObj) [3]);
+  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
+  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
+  (* (--Rsp)) = (Wrd37.Obj);
+  ((Wrd36.pObj) [0]) = (Wrd32.Obj);
   Rsp = (& (Rsp [2]));
-  (Wrd89.Obj) = (Rsp [0]);
-  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
-  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
-  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
-  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
-  Rvl = (current_block [OBJECT_5_0]);
-  Rsp = (& (Rsp [1]));
-  goto pop_return;
-
-DEFLABEL (label_47)
-  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
-    goto label_46;
-  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_17])), (Wrd75.pObj), (Wrd76.Obj));
-
-DEFLABEL (label_35)
-  goto label_45;
-
-DEFLABEL (label_50)
-  if ((Wrd67.Obj) == (Wrd60.Obj))
-    goto label_49;
-  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_16])), (Wrd64.pObj));
-
-DEFLABEL (label_34)
-  (Wrd63.Obj) = Rvl;
-  goto label_48;
-
-DEFLABEL (label_53)
-  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
-    goto label_52;
-  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_15])), (Wrd31.pObj), (Wrd32.Obj));
-
-DEFLABEL (label_33)
-  goto label_51;
-
-DEFLABEL (label_56)
-  if ((Wrd23.Obj) == (Wrd16.Obj))
-    goto label_55;
-  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_14])), (Wrd20.pObj));
-
-DEFLABEL (label_32)
-  (Wrd19.Obj) = Rvl;
-  goto label_54;
-
-DEFLABEL (lambda_44)
-  CLOSURE_HEADER (LABEL_5_11);
-
-DEFLABEL (lambda_13)
-  CLOSURE_INTERRUPT_CHECK (24);
-  (Wrd5.Obj) = (Rsp [0]);
-  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
-  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
-  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
-  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
-  (* (--Rsp)) = (Wrd9.Obj);
-  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
-  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
-  Rsp = (& (Rsp [1]));
-  (* (--Rsp)) = (Wrd9.Obj);
-  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
-  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
-  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
-  if ((Wrd24.uLng) == 50)
-    goto label_68;
-
-DEFLABEL (label_67)
-  Wrd19 = Wrd23;
-
-DEFLABEL (label_66)
-  (* (--Rsp)) = (Wrd19.Obj);
-  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_0]));
-  (Wrd32.Obj) = (Rsp [1]);
-  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
-  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
-  if ((Wrd40.uLng) == 50)
-    goto label_65;
-
-DEFLABEL (label_64)
-  ((Wrd31.pObj) [0]) = (Wrd32.Obj);
-
-DEFLABEL (label_63)
-  (Wrd44.Obj) = (Rsp [0]);
-  Rsp = (& (Rsp [2]));
-  (Wrd45.Obj) = (Rsp [0]);
-  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
-  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
-  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
-  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
-  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
-  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
-  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
-  (* (--Rsp)) = (Wrd53.Obj);
-  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
-  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
-  Rsp = (& (Rsp [1]));
-  (* (--Rsp)) = (Wrd53.Obj);
-  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_1]));
-  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
-  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
-  if ((Wrd68.uLng) == 50)
-    goto label_62;
-
-DEFLABEL (label_61)
-  Wrd63 = Wrd67;
-
-DEFLABEL (label_60)
-  (* (--Rsp)) = (Wrd63.Obj);
-  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_1]));
-  (Wrd76.Obj) = (Rsp [1]);
-  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
-  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
-  if ((Wrd84.uLng) == 50)
-    goto label_59;
-
-DEFLABEL (label_58)
-  ((Wrd75.pObj) [0]) = (Wrd76.Obj);
-
-DEFLABEL (label_57)
-  (Wrd88.Obj) = (Rsp [0]);
-  Rsp = (& (Rsp [2]));
-  (Wrd89.Obj) = (Rsp [0]);
-  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
-  (Wrd91.Obj) = ((Wrd90.pObj) [2]);
-  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
-  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
-  Rvl = (current_block [OBJECT_5_0]);
-  Rsp = (& (Rsp [1]));
-  goto pop_return;
-
-DEFLABEL (label_59)
-  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
-    goto label_58;
-  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_21])), (Wrd75.pObj), (Wrd76.Obj));
+  (Wrd45.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_0]));
+  (Wrd53.Obj) = ((Wrd45.pObj) [0]);
+  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
+  if ((Wrd54.uLng) == 50)
+    goto label_40;
 
 DEFLABEL (label_39)
-  goto label_57;
-
-DEFLABEL (label_62)
-  if ((Wrd67.Obj) == (Wrd60.Obj))
-    goto label_61;
-  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_20])), (Wrd64.pObj));
+  ((Wrd45.pObj) [0]) = (Wrd37.Obj);
 
 DEFLABEL (label_38)
-  (Wrd63.Obj) = Rvl;
-  goto label_60;
-
-DEFLABEL (label_65)
-  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
-    goto label_64;
-  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_19])), (Wrd31.pObj), (Wrd32.Obj));
-
-DEFLABEL (label_37)
-  goto label_63;
-
-DEFLABEL (label_68)
-  if ((Wrd23.Obj) == (Wrd16.Obj))
-    goto label_67;
-  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_18])), (Wrd20.pObj));
+  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_1]));
+  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
+  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
+  if ((Wrd62.uLng) == 50)
+    goto label_37;
 
 DEFLABEL (label_36)
-  (Wrd19.Obj) = Rvl;
-  goto label_66;
+  Wrd57 = Wrd61;
+
+DEFLABEL (label_35)
+  (* (--Rsp)) = (Wrd57.Obj);
+  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_1]));
+  (Wrd70.Obj) = (MAKE_OBJECT (50, 0));
+  (Wrd79.Obj) = ((Wrd69.pObj) [0]);
+  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
+  if ((Wrd80.uLng) == 50)
+    goto label_34;
+
+DEFLABEL (label_33)
+  ((Wrd69.pObj) [0]) = (Wrd70.Obj);
+
+DEFLABEL (label_32)
+  (Wrd84.Obj) = (Rsp [0]);
+  Rsp = (& (Rsp [1]));
+  (* (--Rsp)) = (Wrd84.Obj);
+  (Wrd85.Obj) = (Rsp [1]);
+  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd85.Obj));
+  (Wrd87.Obj) = ((Wrd86.pObj) [2]);
+  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
+  (Wrd89.Obj) = ((Wrd88.pObj) [0]);
+  (* (--Rsp)) = (Wrd89.Obj);
+  ((Wrd88.pObj) [0]) = (Wrd84.Obj);
+  Rsp = (& (Rsp [2]));
+  (Wrd97.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_5_1]));
+  (Wrd105.Obj) = ((Wrd97.pObj) [0]);
+  (Wrd106.uLng) = (OBJECT_TYPE (Wrd105.Obj));
+  if ((Wrd106.uLng) == 50)
+    goto label_31;
+
+DEFLABEL (label_30)
+  ((Wrd97.pObj) [0]) = (Wrd89.Obj);
+
+DEFLABEL (label_29)
+  Rvl = (current_block [OBJECT_5_0]);
+  Rsp = (& (Rsp [1]));
+  goto pop_return;
+
+DEFLABEL (label_31)
+  if ((Wrd105.Obj) == (MAKE_OBJECT (50, 0)))
+    goto label_30;
+  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_17])), (Wrd97.pObj), (Wrd89.Obj));
+
+DEFLABEL (label_24)
+  goto label_29;
+
+DEFLABEL (label_34)
+  if ((Wrd79.Obj) == (Wrd70.Obj))
+    goto label_33;
+  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_16])), (Wrd69.pObj), (Wrd70.Obj));
+
+DEFLABEL (label_23)
+  goto label_32;
+
+DEFLABEL (label_37)
+  if ((Wrd61.Obj) == (MAKE_OBJECT (50, 0)))
+    goto label_36;
+  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_15])), (Wrd58.pObj));
+
+DEFLABEL (label_22)
+  (Wrd57.Obj) = Rvl;
+  goto label_35;
+
+DEFLABEL (label_40)
+  if ((Wrd53.Obj) == (MAKE_OBJECT (50, 0)))
+    goto label_39;
+  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_14])), (Wrd45.pObj), (Wrd37.Obj));
+
+DEFLABEL (label_21)
+  goto label_38;
+
+DEFLABEL (label_43)
+  if ((Wrd27.Obj) == (Wrd18.Obj))
+    goto label_42;
+  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_5_13])), (Wrd17.pObj), (Wrd18.Obj));
+
+DEFLABEL (label_20)
+  goto label_41;
+
+DEFLABEL (label_46)
+  if ((Wrd9.Obj) == (MAKE_OBJECT (50, 0)))
+    goto label_45;
+  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_5_12])), (Wrd6.pObj));
+
+DEFLABEL (label_19)
+  (Wrd5.Obj) = Rvl;
+  goto label_44;
 
 INVOKE_INTERFACE_TARGET_0
 }
@@ -1075,7 +939,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-wrkdir_so_9eab4f30425cd151 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+wrkdir_so_a30a7d06fed422f2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1158,31 +1022,31 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_wrkdir_so_9eab4f30425cd151 [6] =
+static const struct liarc_code_S arr_decl_wrkdir_so_a30a7d06fed422f2 [6] =
   {
     { "wrkdir_so_code_1", 4, wrkdir_so_code_1 },
     { "wrkdir_so_code_2", 6, wrkdir_so_code_2 },
     { "wrkdir_so_code_3", 2, wrkdir_so_code_3 },
     { "wrkdir_so_code_4", 6, wrkdir_so_code_4 },
-    { "wrkdir_so_code_5", 13, wrkdir_so_code_5 },
+    { "wrkdir_so_code_5", 10, wrkdir_so_code_5 },
     { "wrkdir_so_code_6", 4, wrkdir_so_code_6 }
   };
 
 int
-decl_wrkdir_so_9eab4f30425cd151 (void)
+decl_wrkdir_so_a30a7d06fed422f2 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_wrkdir_so_9eab4f30425cd151);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_wrkdir_so_a30a7d06fed422f2);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("wrkdir.so", 3, decl_wrkdir_so_9eab4f30425cd151, wrkdir_so_9eab4f30425cd151)
+DECLARE_COMPILED_CODE ("wrkdir.so", 3, decl_wrkdir_so_a30a7d06fed422f2, wrkdir_so_a30a7d06fed422f2)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_wrkdir_so_data_9eab4f30425cd151 [944] =
-  "\x31\x0c\xd9\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x0d\x24"
+static const unsigned char prog_wrkdir_so_data_a30a7d06fed422f2 [919] =
+  "\x2b\x0c\xd3\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x0d\x24"
   "\x28\xb1\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
   "\xba\x1d\xb0\x82\x88\x1d\xc0\x0d\xbb\x0d\xbc\x25\x28\x0d\xbd\x28"
   "\x0d\xbe\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
@@ -1191,71 +1055,70 @@ static const unsigned char prog_wrkdir_so_data_9eab4f30425cd151 [944] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
   "\x1d\xb0\x85\x88\x1d\xb3\xb4\x25\xb3\xb4\x24\x28\x1b\x28\x0d\x23"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0"
-  "\x86\x88\xb3\x24\x28\x0d\x28\xb5\x28\xb6\x23\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x21\x17\x2b\xbe\x9d\xbd\x88\xb5\xb6\x2a\xb4\x2a\x1b"
-  "\x2a\x1b\x2a\x1e\xb7\x2a\xb2\x2a\x9e\x1b\x0d\x0d\x0d\xb3\xb1\x0d"
-  "\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x47\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x30\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
-  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x30\x2e\x31\x2f\x73\x72"
-  "\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x77\x72\x6b\x64\x69\x72"
-  "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
-  "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x07\x72\x65\x73\x65\x74"
-  "\x21\x14\x65\x76\x65\x6e\x74\x3a\x61\x66\x74\x65\x72\x2d\x72\x65"
-  "\x73\x74\x6f\x72\x65\x03\x02\x04\x14\x61\x64\x64\x2d\x65\x76\x65"
-  "\x6e\x74\x2d\x72\x65\x63\x65\x69\x76\x65\x72\x21\x03\x07\x0a\x81"
-  "\x83\x02\x06\x08\x81\x81\x02\x05\x06\x81\x81\x02\x04\x04\x82\x02"
-  "\x09\x14\x02\x02\x1b\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72"
-  "\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x1d"
-  "\x2a\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72\x65\x63\x74\x6f"
-  "\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x2a\x1c\x2a\x64\x65"
-  "\x66\x61\x75\x6c\x74\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x64"
-  "\x65\x66\x61\x75\x6c\x74\x73\x2a\x03\x03\x12\x70\x61\x74\x68\x6e"
-  "\x61\x6d\x65\x2d\x73\x69\x6d\x70\x6c\x69\x66\x79\x03\x16\x70\x61"
-  "\x74\x68\x6e\x61\x6d\x65\x2d\x61\x73\x2d\x64\x69\x72\x65\x63\x74"
-  "\x6f\x72\x79\x03\x0d\x0e\x81\x85\x02\x0c\x0c\x81\x83\x02\x0b\x0a"
-  "\x81\x83\x02\x0a\x08\x81\x83\x02\x09\x06\x81\x81\x02\x08\x04\x82"
-  "\x02\x0d\x1a\x02\x02\x0f\x06\x81\x81\x02\x0e\x04\x82\x02\x05\x0a"
-  "\x09\x02\x03\x03\x0d\x6e\x65\x77\x2d\x70\x61\x74\x68\x6e\x61\x6d"
-  "\x65\x0a\x02\x0d\x6e\x65\x61\x72\x65\x73\x74\x2d\x63\x6d\x64\x6c"
-  "\x04\x1b\x63\x6d\x64\x6c\x2f\x73\x65\x74\x2d\x64\x65\x66\x61\x75"
-  "\x6c\x74\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x04\x15\x0e\x81"
-  "\x87\x02\x14\x0c\x81\x83\x02\x13\x0a\x81\x83\x02\x12\x08\x81\x83"
-  "\x02\x11\x06\x81\x83\x02\x10\x04\x83\x04\x0d\x1a\x0b\x02\x02\x03"
-  "\x03\x03\x0a\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75"
-  "\x69\x64\x2d\x62\x69\x6e\x64\x03\x22\x1c\x81\x87\x02\x21\x1a\x81"
-  "\x85\x02\x20\x18\x81\x87\x02\x1f\x16\x81\x85\x02\x1e\x14\x81\x83"
-  "\x02\x1d\x12\x81\x87\x02\x1c\x10\x81\x85\x02\x1b\x0e\x81\x87\x02"
-  "\x1a\x0c\x81\x85\x02\x19\x0a\x81\x83\x02\x18\x08\x81\x83\x02\x17"
-  "\x06\x81\x85\x02\x16\x04\x84\x06\x1b\x2a\x02\x02\x04\x10\x6d\x65"
-  "\x72\x67\x65\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x73\x03\x03\x04"
-  "\x26\x0a\x81\x85\x02\x25\x08\x81\x83\x02\x24\x06\x81\x87\x02\x23"
-  "\x04\x83\x04\x09\x15\x04\x04\x0b\x04\x09\x04\x04\x04\x0a\x20\x77"
-  "\x69\x74\x68\x2d\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72\x65"
-  "\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x20\x73"
-  "\x65\x74\x2d\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72\x65\x63"
-  "\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x21\x1b\x77"
-  "\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79"
-  "\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x14\x69\x6e\x69\x74\x69\x61"
-  "\x6c\x69\x7a\x65\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x05\x10\x64"
-  "\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x03"
-  "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
+  "\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x86\x88\xb3\x24\x28\x0d"
+  "\x28\xb5\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
+  "\xbe\x9d\xbd\x88\xb5\xb6\x2a\xb4\x2a\x1b\x2a\x1b\x2a\x1e\xb7\x2a"
+  "\xb2\x2a\x9e\x1b\x0d\x0d\x0d\xb3\xb1\x0d\x9e\x28\x0d\x26\x22\x29"
+  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
+  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x77\x72\x6b\x64\x69\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
+  "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
+  "\x07\x72\x65\x73\x65\x74\x21\x14\x65\x76\x65\x6e\x74\x3a\x61\x66"
+  "\x74\x65\x72\x2d\x72\x65\x73\x74\x6f\x72\x65\x03\x02\x04\x14\x61"
+  "\x64\x64\x2d\x65\x76\x65\x6e\x74\x2d\x72\x65\x63\x65\x69\x76\x65"
+  "\x72\x21\x03\x07\x0a\x81\x83\x02\x06\x08\x81\x81\x02\x05\x06\x81"
+  "\x81\x02\x04\x04\x82\x02\x09\x14\x02\x02\x1b\x77\x6f\x72\x6b\x69"
+  "\x6e\x67\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74"
+  "\x68\x6e\x61\x6d\x65\x1d\x2a\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64"
+  "\x69\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d"
+  "\x65\x2a\x1c\x2a\x64\x65\x66\x61\x75\x6c\x74\x2d\x70\x61\x74\x68"
+  "\x6e\x61\x6d\x65\x2d\x64\x65\x66\x61\x75\x6c\x74\x73\x2a\x03\x03"
+  "\x12\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x73\x69\x6d\x70\x6c\x69"
+  "\x66\x79\x03\x16\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x61\x73\x2d"
+  "\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x03\x0d\x0e\x81\x85\x02\x0c"
+  "\x0c\x81\x83\x02\x0b\x0a\x81\x83\x02\x0a\x08\x81\x83\x02\x09\x06"
+  "\x81\x81\x02\x08\x04\x82\x02\x0d\x1a\x02\x02\x0f\x06\x81\x81\x02"
+  "\x0e\x04\x82\x02\x05\x0a\x09\x02\x03\x03\x0d\x6e\x65\x77\x2d\x70"
+  "\x61\x74\x68\x6e\x61\x6d\x65\x0a\x02\x0d\x6e\x65\x61\x72\x65\x73"
+  "\x74\x2d\x63\x6d\x64\x6c\x04\x1b\x63\x6d\x64\x6c\x2f\x73\x65\x74"
+  "\x2d\x64\x65\x66\x61\x75\x6c\x74\x2d\x64\x69\x72\x65\x63\x74\x6f"
+  "\x72\x79\x04\x15\x0e\x81\x87\x02\x14\x0c\x81\x83\x02\x13\x0a\x81"
+  "\x83\x02\x12\x08\x81\x83\x02\x11\x06\x81\x83\x02\x10\x04\x83\x04"
+  "\x0d\x1a\x0b\x02\x02\x03\x03\x03\x0a\x05\x13\x73\x68\x61\x6c\x6c"
+  "\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x03\x1f\x16"
+  "\x81\x83\x02\x1e\x14\x81\x85\x02\x1d\x12\x81\x83\x02\x1c\x10\x81"
+  "\x83\x02\x1b\x0e\x81\x85\x02\x1a\x0c\x81\x83\x02\x19\x0a\x81\x83"
+  "\x02\x18\x08\x81\x83\x02\x17\x06\x81\x85\x02\x16\x04\x84\x06\x15"
+  "\x24\x02\x02\x04\x10\x6d\x65\x72\x67\x65\x2d\x70\x61\x74\x68\x6e"
+  "\x61\x6d\x65\x73\x03\x03\x04\x23\x0a\x81\x85\x02\x22\x08\x81\x83"
+  "\x02\x21\x06\x81\x87\x02\x20\x04\x83\x04\x09\x15\x04\x04\x0b\x04"
+  "\x09\x04\x04\x04\x0a\x20\x77\x69\x74\x68\x2d\x77\x6f\x72\x6b\x69"
+  "\x6e\x67\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74"
+  "\x68\x6e\x61\x6d\x65\x20\x73\x65\x74\x2d\x77\x6f\x72\x6b\x69\x6e"
+  "\x67\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68"
+  "\x6e\x61\x6d\x65\x21\x1b\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69"
+  "\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65"
+  "\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x70\x61\x63\x6b"
+  "\x61\x67\x65\x21\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c"
+  "\x74\x69\x70\x6c\x65\x02\x03\x08\x80\x80\x04\x02\x06\x81\x81\x02"
+  "\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-wrkdir_so_data_9eab4f30425cd151 (entry_count_t dispatch_base)
+wrkdir_so_data_a30a7d06fed422f2 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_wrkdir_so_data_9eab4f30425cd151 [0]))), (sizeof (prog_wrkdir_so_data_9eab4f30425cd151)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_wrkdir_so_data_a30a7d06fed422f2 [0]))), (sizeof (prog_wrkdir_so_data_a30a7d06fed422f2)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("wrkdir.so", wrkdir_so_data_9eab4f30425cd151)
+DECLARE_COMPILED_DATA_NS ("wrkdir.so", wrkdir_so_data_a30a7d06fed422f2)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("wrkdir.so", "c91596c78e2520e8")
+DECLARE_DYNAMIC_INITIALIZATION ("wrkdir.so", "fc387eb220d1623a")
